==> kubernetes-model-1.0.57-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HTTPIngressRuleValueFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.validation.Valid;
import java.util.ArrayList;
import java.lang.Object;
import io.fabric8.kubernetes.api.builder.Nested;

public class HTTPIngressRuleValueFluentImpl<A extends HTTPIngressRuleValueFluent<A>> extends BaseFluent<A> implements HTTPIngressRuleValueFluent<A>{

    private List<VisitableBuilder<? extends HTTPIngressPath,?>> paths =  new ArrayList<VisitableBuilder<? extends HTTPIngressPath,?>>();

    public HTTPIngressRuleValueFluentImpl(){
    }
    public HTTPIngressRuleValueFluentImpl(HTTPIngressRuleValue instance){
            this.withPaths(instance.getPaths()); 
    }

    public A addToPaths(HTTPIngressPath... items){
            for (HTTPIngressPath item : items) {HTTPIngressPathBuilder builder = new HTTPIngressPathBuilder(item);_visitables.add(builder);this.paths.add(builder);} return (A)this;
    }

    public A removeFromPaths(HTTPIngressPath... items){
            for (HTTPIngressPath item : items) {HTTPIngressPathBuilder builder = new HTTPIngressPathBuilder(item);_visitables.remove(builder);this.paths.remove(builder);} return (A)this;
    }

    public List<HTTPIngressPath> getPaths(){
            return build(paths);
    }

    public A withPaths(List<HTTPIngressPath> paths){
            this.paths.clear();
            if (paths != null) {for (HTTPIngressPath item : paths){this.addToPaths(item);}} return (A) this;
    }

    public A withPaths(HTTPIngressPath... paths){
            this.paths.clear(); if (paths != null) {for (HTTPIngressPath item :paths){ this.addToPaths(item);}} return (A) this;
    }

    public HTTPIngressRuleValueFluent.PathsNested<A> addNewPath(){
            return new PathsNestedImpl();
    }

    public HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(HTTPIngressPath item){
            return new PathsNestedImpl(item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HTTPIngressRuleValueFluentImpl that = (HTTPIngressRuleValueFluentImpl) o;
            if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
            return true;
    }


    public class PathsNestedImpl<N> extends HTTPIngressPathFluentImpl<HTTPIngressRuleValueFluent.PathsNested<N>> implements HTTPIngressRuleValueFluent.PathsNested<N>,Nested<N>{

            private final HTTPIngressPathBuilder builder;
    
            PathsNestedImpl(){
                    this.builder = new HTTPIngressPathBuilder(this);
            }
            PathsNestedImpl(HTTPIngressPath item){
                    this.builder = new HTTPIngressPathBuilder(this, item);
            }
    
    public N and(){
            return (N) HTTPIngressRuleValueFluentImpl.this.addToPaths(builder.build());
    }
    public N endPath(){
            return and();
    }

}


}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HTTPIngressRuleValueFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class HTTPIngressRuleValueFluentImpl<A extends HTTPIngressRuleValueFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HTTPIngressRuleValueFluent<A>{

    private List<VisitableBuilder<? extends HTTPIngressPath,?>> paths =  new ArrayList<VisitableBuilder<? extends HTTPIngressPath,?>>();

    public HTTPIngressRuleValueFluentImpl(){
    }
    public HTTPIngressRuleValueFluentImpl(HTTPIngressRuleValue instance){
            this.withPaths(instance.getPaths()); 
    }

    public A addToPaths(HTTPIngressPath... items){
            for (HTTPIngressPath item : items) {HTTPIngressPathBuilder builder = new HTTPIngressPathBuilder(item);_visitables.add(builder);this.paths.add(builder);} return (A)this;
    }

    public A removeFromPaths(HTTPIngressPath... items){
            for (HTTPIngressPath item : items) {HTTPIngressPathBuilder builder = new HTTPIngressPathBuilder(item);_visitables.remove(builder);this.paths.remove(builder);} return (A)this;
    }

    public List<HTTPIngressPath> getPaths(){
            return build(paths);
    }

    public A withPaths(List<HTTPIngressPath> paths){
            _visitables.removeAll(this.paths);
            this.paths.clear();
            if (paths != null) {for (HTTPIngressPath item : paths){this.addToPaths(item);}} return (A) this;
    }

    public A withPaths(HTTPIngressPath... paths){
            this.paths.clear(); if (paths != null) {for (HTTPIngressPath item :paths){ this.addToPaths(item);}} return (A) this;
    }

    public HTTPIngressRuleValueFluent.PathsNested<A> addNewPath(){
            return new PathsNestedImpl();
    }

    public HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(HTTPIngressPath item){
            return new PathsNestedImpl(item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HTTPIngressRuleValueFluentImpl that = (HTTPIngressRuleValueFluentImpl) o;
            if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
            return true;
    }


    public class PathsNestedImpl<N> extends HTTPIngressPathFluentImpl<HTTPIngressRuleValueFluent.PathsNested<N>> implements HTTPIngressRuleValueFluent.PathsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final HTTPIngressPathBuilder builder;
    
            PathsNestedImpl(HTTPIngressPath item){
                    this.builder = new HTTPIngressPathBuilder(this, item);
            }
            PathsNestedImpl(){
                    this.builder = new HTTPIngressPathBuilder(this);
            }
    
    public N and(){
            return (N) HTTPIngressRuleValueFluentImpl.this.addToPaths(builder.build());
    }
    public N endPath(){
            return and();
    }

}


}
